@@ -1,4 +1,7 @@
-from itertools import groupby
+import os
+from collections import OrderedDict
+from typing import List, Optional
+
 import sqlalchemy as sa
 from postgresql_audit.flask import versioning_manager
 
@@ -12,14 +15,28 @@ from sqlalchemy_api_handler.utils.datum import datum_with_relationships_from, \
 class Activate(Save):
     @staticmethod
     def activate(*activities,
-                 with_check_not_soft_deleted=True):
+                 with_check_not_soft_deleted=True,
+                 ordered_table: Optional[List] = None):
 
-        sorted_activities = sorted(activities,
-                                   key=lambda activity: str(activity.dateCreated) + str(activity.entityIdentifier))
-        for (entity_identifier, grouped_activities) in groupby(Activate.remove_existing_activities(sorted_activities),
-                                                               key=lambda activity: activity.entityIdentifier):
-            grouped_activities = list(grouped_activities)
-            first_activity = grouped_activities[0]
+        def sort_activities(record):
+            if ordered_table:
+                return (ordered_table.index(record.table_name) if record.table_name in ordered_table
+                        else len(ordered_table) + 1,
+                        record.dateCreated)
+            return record.dateCreated
+
+        sorted_activities = sorted(activities, key=lambda act: sort_activities(act))
+
+        sorted_activities_by_identifier = OrderedDict()
+        for activity in sorted_activities:
+            entity_identifier = activity.entityIdentifier
+            if entity_identifier in sorted_activities_by_identifier:
+                sorted_activities_by_identifier[entity_identifier].append(activity)
+            else:
+                sorted_activities_by_identifier[entity_identifier] = [activity]
+
+        for (entity_identifier, grouped_activities) in sorted_activities_by_identifier.items():
+            first_activity = list(grouped_activities)[0]
             table_name = first_activity.table_name
 
             model = Save.model_from_table_name(table_name)
@@ -35,7 +52,7 @@ class Activate(Save):
                 remaining_activities = grouped_activities[1:]
                 entity = first_activity.entity
             else:
-                remaining_activities = grouped_activities
+                remaining_activities = list(grouped_activities)
 
             update_activities = []
             delete_activity = None
@@ -53,6 +70,12 @@ class Activate(Save):
             if delete_activity:
                 Activate._activate_deletion(delete_activity)
 
+            session = Activate.get_db().session
+            if len(session.dirty) > int(os.environ.get('SQLAAH_ACTIVATE_BATCH_INSERTS_BY', 10)):
+                session.commit()
+
+        Activate.get_db().session.commit()
+
     @staticmethod
     def _activate_deletion(activity):
         model = Save.model_from_table_name(activity.table_name)
@@ -102,17 +125,29 @@ class Activate(Save):
         already_activities_since_min_date = activity_class.query \
                                                            .filter(entity.join_self_activities(),
                                                                    activity_class.dateCreated >= min_date,
-                                                                   activity_class.verb == 'update') \
+                                                                   ((activity_class.verb == 'insert') | \
+                                                                    (activity_class.verb == 'update'))) \
                                                            .all()
 
-        all_activities_since_min_date = sorted(already_activities_since_min_date + activities,
+        potential_existing_activities_dict = { (str(a.dateCreated), str(a.entityIdentifier)) : a
+                                               for a in already_activities_since_min_date }
+        unknown_activities = []
+        for activity in activities:
+            if not potential_existing_activities_dict.get((str(activity.dateCreated),
+                                                           str(activity.entityIdentifier))):
+                unknown_activities.append(activity)
+        if len(unknown_activities) == 0:
+            return
+
+        update_activities_since_min_date = [a for a in already_activities_since_min_date if a.verb == 'update']
+        all_activities_since_min_date = sorted(update_activities_since_min_date + unknown_activities,
                                                key=lambda activity: activity.dateCreated)
 
         model = Save.model_from_table_name(entity.__tablename__)
         merged_datum = merged_datum_from_activities(entity, all_activities_since_min_date)
 
         database = Activate.get_db()
-        database.session.add_all(activities)
+        database.session.add_all(unknown_activities)
         if model.id.key in merged_datum:
             del merged_datum[model.id.key]
         with versioning_manager.disable(database.session):
@@ -130,20 +165,13 @@ class Activate(Save):
         Activate.activity_cls = activity_cls
 
     @staticmethod
-    def remove_existing_activities(activities):
+    def unknown_activities_from(activities):
         if not activities:
             return []
         activity_class = Activate.get_activity()
         potential_existing_activities = activity_class.query.filter(activity_class.entityIdentifier.in_([a.entityIdentifier for a in activities])) \
                                                             .filter(activity_class.dateCreated.in_([a.dateCreated for a in activities])) \
                                                             .all()
-        potential_existing_activities_dict = { (str(a.dateCreated), str(a.entityIdentifier)) : a for a in potential_existing_activities }
-        unknown_activities = []
-        for activity in activities:
-            existing_activity = potential_existing_activities_dict.get((str(activity.dateCreated), str(activity.entityIdentifier)))
-            if not existing_activity:
-                unknown_activities.append(activity)
-        return unknown_activities
 
     @classmethod
     def models(cls):
