@@ -1,22 +1,18 @@
-from datetime import datetime
+# pylint: disable=C0103
+
 import uuid
-from sqlalchemy import Column, String
 from sqlalchemy.dialects.postgresql import UUID
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.ext.hybrid import hybrid_property
-from sqlalchemy.orm import relationship, synonym
+from sqlalchemy.orm import synonym
 
 from sqlalchemy_api_handler.bases.errors import ActivityError
-from sqlalchemy_api_handler.utils.datum import columns_in, \
-                                               relationships_in, \
-                                               synonyms_in
 import sqlalchemy_api_handler.utils.date as date_helper
-from sqlalchemy_api_handler.utils.dehumanize import dehumanize_ids_in
-from sqlalchemy_api_handler.utils.humanize import humanize, \
-                                                  humanize_ids_in
+from sqlalchemy_api_handler.utils.datum import saveable_datum_from, \
+                                               serializable_datum_from
 
 
-class ActivityMixin(object):
+class ActivityMixin:
 
     _entityIdentifier = None
 
@@ -36,8 +32,7 @@ class ActivityMixin(object):
     def datum(self):
         if self.data is None:
             return None
-        model = self.model
-        return synonyms_in(humanize_ids_in(self.data, self.model), model)
+        return serializable_datum_from(self.data, self.model)
 
     @hybrid_property
     def entityIdentifier(self):
@@ -45,8 +40,9 @@ class ActivityMixin(object):
             return self._entityIdentifier
         activity_identifier = self.data.get('activityIdentifier')
         if activity_identifier:
-            self._entityIdentifier = activity_identifier
-            return uuid.UUID(self._entityIdentifier)
+            self._entityIdentifier = uuid.UUID(activity_identifier)
+            return self._entityIdentifier
+        return None
 
     @entityIdentifier.expression
     def entityIdentifier(cls):
@@ -54,6 +50,8 @@ class ActivityMixin(object):
 
     @entityIdentifier.setter
     def entityIdentifier(self, value):
+        if isinstance(value, str):
+            value = uuid.UUID(value)
         self._entityIdentifier = value
 
     @property
@@ -76,29 +74,29 @@ class ActivityMixin(object):
     @property
     def entity(self):
         model = self.model
-        activity_identifier = self.data.get('activityIdentifier',
-                                            self._entityIdentifier)
+        activity_identifier = self.entityIdentifier
         if activity_identifier:
             return model.query.filter_by(activityIdentifier=activity_identifier).one()
+        return None
 
     @property
     def oldDatum(self):
         if self.old_data is None:
             return None
         model = self.model
-        return synonyms_in(humanize_ids_in(self.old_data, model), model)
+        return serializable_datum_from(self.old_data, model)
 
     @property
     def patch(self):
         if self.changed_data is None:
             return None
         model = self.model
-        return synonyms_in(humanize_ids_in(self.changed_data, model), model)
+        return serializable_datum_from(self.changed_data, model)
 
     @patch.setter
     def patch(self, value):
         model = self.model
-        self.changed_data = columns_in(dehumanize_ids_in(value, model), model)
+        self.changed_data = saveable_datum_from(value, model)
 
     def modify(self, datum, **kwargs):
         if 'modelName' in datum and 'tableName' in datum:
