@@ -9,7 +9,7 @@ class NonDehumanizableId(Exception):
     pass
 
 
-def dehumanize(publicId):
+def dehumanize(public_id: str):
     """
     Get back an integer from a human-compatible ID
     This library creates IDs for use in our URLs,
@@ -18,13 +18,14 @@ def dehumanize(publicId):
     We use base32, but replace O and I, which can be mistaken for 0 and 1
     by 8 and 9
     """
-    if publicId is None:
+    if public_id is None \
+            or (isinstance(public_id, str) and public_id.strip() == ''):
         return None
-    missing_padding = len(publicId) % 8
+    missing_padding = len(public_id) % 8
     if missing_padding != 0:
-        publicId += '=' * (8 - missing_padding)
+        public_id += '=' * (8 - missing_padding)
     try:
-        xbytes = b32decode(publicId.replace('8', 'O').replace('9', 'I'))
+        xbytes = b32decode(public_id.replace('8', 'O').replace('9', 'I'))
     except binascii.Error:
         raise NonDehumanizableId('id non dehumanizable')
     return int_from_bytes(xbytes)
@@ -34,17 +35,6 @@ def int_from_bytes(xbytes):
     return int.from_bytes(xbytes, 'big')
 
 
-def dehumanize_ids_in(datum, model):
-    if datum is None:
-        return None
-    dehumanized_datum = {**datum}
-    for (key, value) in datum.items():
-        if hasattr(model, key):
-            if is_id_column(getattr(model, key)):
-                dehumanized_datum[key] = dehumanize(value)
-    return dehumanized_datum
-
-
 def dehumanize_if_needed(column, value: Any) -> Any:
     if is_id_column(column):
         return dehumanize(value)
